@@ -20,4 +20,7 @@ $(function ($) {
         });
         table.find('input[name="selectall"]').prop('checked', false);
     });
-});
\ No newline at end of file
+    $('.datepicker').datepicker({autoclose: true}).click(function(){
+        $('input.datepicker').not(this).datepicker('hide');
+    });
+});
