@@ -23,7 +23,7 @@ def bob_icon(name, is_white=False):
 
 @register.inclusion_tag('bob/main_menu.html')
 def main_menu(items, selected, title=None, search=None, white=False,
-              position=''):
+              position='', title_url="/"):
     """
     Show main menu bar.
 
@@ -42,6 +42,7 @@ def main_menu(items, selected, title=None, search=None, white=False,
         'search': search,
         'position': position,
         'white': bool(white),
+        'title_url': title_url,
         }
 
 
@@ -236,10 +237,11 @@ def table_header(columns=None, url_query=None, sort=None, fugue_icons=False,
     Render a table header with sorted column options
 
     :param columns: a list of objects of
-    type :py:class:bob.data_table.DataTableColumn
+                    type :py:class:bob.data_table.DataTableColumn
     :param url_query: The query parameters to add to all page links
     :param sort: means that the column is now sorted
     :param fugue_icons: Whether to use Fugue icons or Bootstrap icons.
+
     """
     return {
         'columns': columns,
